Package: eulerr
Title: Area-Proportional Euler and Venn Diagrams with Ellipses
Version: 7.0.2
Authors@R: c(person("Johan", "Larsson", email = "johanlarsson@outlook.com",
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-4029-5945")),
             person("A. Jonathan R.", "Godfrey", role = "ctb"),
             person("Peter", "Gustafsson", role = "ctb"),
             person("David H.", "Eberly", role = "ctb",
                    comment = "geometric algorithms"),
             person("Emanuel", "Huber", role = "ctb",
                    comment = "root solver code"),
             person("Florian", "Privé", role = "ctb"))
Description: Generate area-proportional Euler diagrams
    using numerical optimization. An Euler diagram is a generalization of a Venn
    diagram, relaxing the criterion that all interactions need to be
    represented. Diagrams may be fit with ellipses and circles via
    a wide range of inputs and can be visualized in numerous ways.
Depends: R (>= 3.3.0)
Imports: GenSA, graphics, grDevices, grid, polyclip, polylabelr, Rcpp,
        stats, utils
Suggests: covr, knitr, lattice, pBrackets, RConics, rmarkdown,
        testthat, spelling
LinkingTo: Rcpp (>= 0.12.12), RcppArmadillo (>= 0.7.600.1.0)
License: GPL-3
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
URL: https://github.com/jolars/eulerr, https://jolars.github.io/eulerr/
BugReports: https://github.com/jolars/eulerr/issues
RoxygenNote: 7.2.3
Language: en-US
NeedsCompilation: yes
Packaged: 2024-03-28 10:02:12 UTC; gerd-jln
Author: Johan Larsson [aut, cre] (<https://orcid.org/0000-0002-4029-5945>),
  A. Jonathan R. Godfrey [ctb],
  Peter Gustafsson [ctb],
  David H. Eberly [ctb] (geometric algorithms),
  Emanuel Huber [ctb] (root solver code),
  Florian Privé [ctb]
Maintainer: Johan Larsson <johanlarsson@outlook.com>
Repository: CRAN
Date/Publication: 2024-03-28 15:40:09 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-24 15:44:10 UTC; unix
Archs: eulerr.so.dSYM
