# Generated by roxygen2: do not edit by hand

S3method("/",eulergram)
S3method("|",eulergram)
S3method(coef,euler)
S3method(euler,data.frame)
S3method(euler,default)
S3method(euler,list)
S3method(euler,matrix)
S3method(euler,table)
S3method(fitted,euler)
S3method(makeContent,EulerTags)
S3method(makeContext,EulerPanel)
S3method(plot,euler)
S3method(plot,eulergram)
S3method(plot,eulerr_venn)
S3method(plot,venn)
S3method(print,euler)
S3method(print,eulergram)
S3method(print,eulerr_venn)
S3method(print,venn)
S3method(residuals,euler)
S3method(venn,data.frame)
S3method(venn,default)
S3method(venn,list)
S3method(venn,matrix)
S3method(venn,table)
export(error_plot)
export(euler)
export(eulerr_options)
export(venn)
import(grid)
useDynLib(eulerr, .registration = TRUE)
