% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label_placement.R
\name{run_placement_pass}
\alias{run_placement_pass}
\title{Single placement pass: measure tags, call the Rust FFI, return the
placement records and the canvas bbox returned by eunoia.}
\usage{
run_placement_pass(
  centers,
  container_data,
  shapes,
  labels_gp,
  quantities_gp,
  annotations_gp,
  padding,
  placement_opts,
  do_complement_label,
  xlim,
  ylim,
  n_vertices,
  label_precision
)
}
\description{
Single placement pass: measure tags, call the Rust FFI, return the
placement records and the canvas bbox returned by eunoia.
}
\keyword{internal}
