% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extendr-wrappers.R
\name{polygon_clip_rust}
\alias{polygon_clip_rust}
\title{Clip a (possibly multi-polygon) subject path against a single clip
polygon. Mirrors the slice of \code{polyclip::polyclip} behavior eulerr
actually uses at the stripe-pattern site.}
\usage{
polygon_clip_rust(subject_x, subject_y, subject_id_lengths, clip_x, clip_y, op)
}
\description{
Clip a (possibly multi-polygon) subject path against a single clip
polygon. Mirrors the slice of \code{polyclip::polyclip} behavior eulerr
actually uses at the stripe-pattern site.
}
\keyword{internal}
