% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup_geometry.R
\name{setup_geometry}
\alias{setup_geometry}
\title{Compute geometries and label locations}
\usage{
setup_geometry(
  x,
  fills,
  edges,
  labels,
  quantities,
  annotations,
  n,
  merged_sets,
  placement_opts = NULL,
  do_complement_label = FALSE
)
}
\arguments{
\item{x}{an object of class 'euler'}

\item{fills}{fills}

\item{edges}{edges}

\item{labels}{labels}

\item{quantities}{quantities}

\item{n}{number of vertices to use to render each ellipse}

\item{merged_sets}{which sets have been merged?}
}
\value{
a list object with slots for the various objects
}
\description{
Compute geometries and label locations
}
\keyword{internal}
