% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extendr-wrappers.R
\name{max_sets_default}
\alias{max_sets_default}
\title{Default number of sets that \code{eunoia} accepts before rejecting a spec.
Used by the R-side input validator so the cap is not hardcoded.}
\usage{
max_sets_default()
}
\description{
Default number of sets that \code{eunoia} accepts before rejecting a spec.
Used by the R-side input validator so the cap is not hardcoded.
}
\keyword{internal}
