% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label_placement.R
\name{resolve_placement_opts}
\alias{resolve_placement_opts}
\title{Merge user-supplied placement options onto the defaults.}
\usage{
resolve_placement_opts(opts)
}
\description{
Merge user-supplied placement options onto the defaults.
}
\keyword{internal}
