% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extendr-wrappers.R
\name{max_sets_hard_cap}
\alias{max_sets_hard_cap}
\title{Absolute upper bound on the number of sets that \code{eunoia} can represent
in a single diagram. Used by the R-side input validator so the cap is
not hardcoded.}
\usage{
max_sets_hard_cap()
}
\description{
Absolute upper bound on the number of sets that \code{eunoia} can represent
in a single diagram. Used by the R-side input validator so the cap is
not hardcoded.
}
\keyword{internal}
