% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_diagram.R
\name{ellipse_frame_to_shapes}
\alias{ellipse_frame_to_shapes}
\title{Promote a legacy 5-column ellipse data frame (h, k, a, b, phi) into the
wide \verb{$shapes} schema. Used by the \code{venn()} path, where the precomputed
venn-shape lookup is still expressed as ellipses.}
\usage{
ellipse_frame_to_shapes(fpar, shape)
}
\description{
Promote a legacy 5-column ellipse data frame (h, k, a, b, phi) into the
wide \verb{$shapes} schema. Used by the \code{venn()} path, where the precomputed
venn-shape lookup is still expressed as ellipses.
}
\keyword{internal}
