% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label_placement.R
\name{split_waypoints}
\alias{split_waypoints}
\title{Split a placement's flat \code{leader_waypoints_x} / \verb{_y} / \verb{_lengths}
return triple into a per-label list of \code{list(x = ..., y = ...)}
coordinate pairs. Each list element has length-\code{lengths[i]} \code{x}/\code{y}
vectors (often \code{0} — straight leaders carry no waypoints).}
\usage{
split_waypoints(placements)
}
\description{
Split a placement's flat \code{leader_waypoints_x} / \verb{_y} / \verb{_lengths}
return triple into a per-label list of \code{list(x = ..., y = ...)}
coordinate pairs. Each list element has length-\code{lengths[i]} \code{x}/\code{y}
vectors (often \code{0} — straight leaders carry no waypoints).
}
\keyword{internal}
