% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{is_false}
\alias{is_false}
\title{Check if object is strictly FALSE}
\usage{
is_false(x)
}
\arguments{
\item{x}{object to check}
}
\value{
A logical.
}
\description{
Check if object is strictly FALSE
}
\keyword{internal}
